﻿using Infragistics.Olap.FlatData;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Data;
using System.ComponentModel;

namespace xamPivotGridCellEditing
{
    public class SampleFlatData : FlatDataSource, INotifyPropertyChanged
    {
        public SampleFlatData()
        {
            SalesCollectionTest collection = new SalesCollectionTest();
            this.ItemsSource = CollectionViewSource.GetDefaultView(collection.Items);
            this.Cube = FlatDataSource.GenerateInitialCube("Sale");
            this.Rows = FlatDataSource.GenerateInitialItems("[City].[City]");
            this.Columns = FlatDataSource.GenerateInitialItems("[Product].[Product]");
            this.Measures = FlatDataSource.GenerateInitialItems("AmountOfSale, NumberOfUnits, UnitPrice");

            CubeMetadata cubeMetadata = new CubeMetadata();
            cubeMetadata.DisplayName = "Sale";
            cubeMetadata.DataTypeFullName = typeof(Sale).FullName;
            cubeMetadata.DimensionSettings.Add(new DimensionMetadata()
            {
                SourcePropertyName = "AmountOfSale",
                DisplayName = "AmountOfSale",
                DisplayFormat = "{0:F3}",
                DimensionType = DimensionType.Measure
            });
            cubeMetadata.DimensionSettings.Add(new DimensionMetadata()
            {
                SourcePropertyName = "NumberOfUnits", // Units Sold
                DisplayName = "NumberOfUnits",
                DimensionType = DimensionType.Measure
            });
            cubeMetadata.DimensionSettings.Add(new DimensionMetadata()
            {
                SourcePropertyName = "UnitPrice",
                DisplayName = "UnitPrice",
                DisplayFormat = "{0:F3}",
                DimensionType = DimensionType.Measure
            });

            cubeMetadata.DimensionSettings.Add(new DimensionMetadata()
            {
                SourcePropertyName = "Product",
                DisplayName = "Product"
            });
            cubeMetadata.DimensionSettings.Add(new DimensionMetadata()
            {
                SourcePropertyName = "City",
                DisplayName = "City"
            });
            cubeMetadata.DimensionSettings.Add(new DimensionMetadata()
            {
                SourcePropertyName = "Seller",
                DisplayName = "Seller"
            });

            this.CubesSettings.Add(cubeMetadata);

            HierarchyDescriptor<Sale> sellerHierarchy = new HierarchyDescriptor<Sale>(p => p.Seller);
            sellerHierarchy.HierarchyDisplayName = "Seller";
            sellerHierarchy.AddLevel(p =>
                "All Sellers",
                "All Sellers"
                );
            sellerHierarchy.AddLevel(p =>
                p.Seller.Name,
                "Seller"
                );
            this.AddHierarchyDescriptor(sellerHierarchy);

            HierarchyDescriptor<Sale> productHierarchy = new HierarchyDescriptor<Sale>(p => p.Product);
            productHierarchy.HierarchyDisplayName ="Product";
            productHierarchy.AddLevel(p =>
               "All Products",
               "All Products"
                );
            productHierarchy.AddLevel(p =>
                p.Product.Name,
                "Product"
                );
            this.AddHierarchyDescriptor(productHierarchy);

            HierarchyDescriptor<Sale> locationHierarchy = new HierarchyDescriptor<Sale>(p => p.City);

            locationHierarchy.HierarchyDisplayName = "City";
            locationHierarchy.AddLevel(p =>
                "All Cities",
                "All Cities"
                );
            locationHierarchy.AddLevel(p =>
                p.City,
                "City"
                );
            this.AddHierarchyDescriptor(locationHierarchy);
        }
    }
}
